@@ -3,7 +3,7 @@ import numpy as np
 import pandas as pd
 from sklearn.metrics import balanced_accuracy_score
 from lightwood.api.types import ProblemDefinition
-from lightwood.api.high_level import predictor_from_problem, json_ai_from_problem, JsonAI, code_from_json_ai, predictor_from_code  # noqa
+from lightwood.api.high_level import predictor_from_problem  # noqa
 np.random.seed(42)
 
 
@@ -69,23 +69,3 @@ class TestBasic(unittest.TestCase):
         self.assertTrue(balanced_accuracy_score(test['target'], predictions['prediction']) > 0.5)
         self.assertTrue('confidence' not in predictions.columns)
 
-    def test_3_test_tempscale_analysis(self):
-        # Create base json ai
-        df = pd.read_csv('tests/data/hdi.csv').iloc[0:100]
-        pdef = ProblemDefinition.from_dict({'target': 'Development Index',
-                                            'time_aim': 20,
-                                            'use_default_analysis': False
-                                            })
-        json_ai = json_ai_from_problem(df, pdef)
-
-        # modify it
-        json_ai_dump = json_ai.to_dict()
-        json_ai_dump['analysis_blocks'] = [{'module': 'TempScaler', 'args': {}}, {'module': 'ConfStats', 'args': {}}]
-        json_ai = JsonAI.from_dict(json_ai_dump)
-
-        # create a predictor from it
-        code = code_from_json_ai(json_ai)
-        predictor = predictor_from_code(code)
-        predictor.learn(df)
-        row_insights = predictor.predict(df)
-        assert 'confidence' in row_insights.columns
